@@ -117,7 +117,7 @@ class ImagesExtractor(object):
 
 
 class ClassifyFiles(object):
-    def _init_(self, SAVE_IMAGES_HERE, classification_zip):
+    def __init__(self, SAVE_IMAGES_HERE, classification_zip):
         self.SAVE_IMAGES_HERE = SAVE_IMAGES_HERE
         self.classification_zip = classification_zip
         self.images = []
@@ -320,7 +320,7 @@ class ClassifyFiles(object):
             except:
                 os.mkdir(f"{self.SAVE_IMAGES_HERE}/{label}/")
                 shutil.move(src_path, dst_path)
-                
+
 class extract_info(object):
     def __init__(self, img_path):
         self.img_path = img_path
